@@ -1,14 +1,17 @@
 package JSON::ize;
 use base Exporter;
-use JSON 2.00;
+use JSON::MaybeXS;
+use YAML::Any qw/Dump Load LoadFile DumpFile/;
+use Try::Tiny;
 use strict;
 use warnings;
 
-our $JOBJ = JSON->new();
+our $JOBJ = JSON::MaybeXS->new();
+our $YOBJ;
 our $_last_out = "";
 
 our @EXPORT = qw/jsonize jsonise J parsej pretty_json ugly_json/;
-our $VERSION = "0.104";
+our $VERSION = "0.200";
 
 sub jobj { $JOBJ }
 
@@ -35,7 +38,22 @@ sub jsonize (;$) {
 	open $f, "$inp" or die "Problem with file '$inp' : $!";
       }
       $j = <$f>;
-      return $_last_out = jobj()->decode($j);
+      try {
+        $_last_out = jobj()->decode($j);
+      } catch {
+        /at character offset/ && do { # JSON error
+          my $jerr = $_;
+          if (looks_like_json($j)) { # probably really was JSON
+            die "JSON decode barfed.\nJSON err: $jerr"
+          }
+          try { # might be YAML
+            $_last_out = Load($j);
+          } catch {
+            die "Both JSON and YAML decodes barfed.\nJSON err: $jerr\nYAML err: $_";
+          };
+        };
+      };
+      return $_last_out;
     }
   }
 }
@@ -58,12 +76,16 @@ sub looks_like_json {
 
 =head1 NAME
 
- JSON::ize - Use JSON easily in one-liners
+ JSON::ize - Use JSON easily in one-liners - now with YAMLific action
 
 =head1 SYNOPSIS
 
  $ perl -MJSON::ize -le '$j=jsonize("my.json"); print $j->{thingy};'
 
+ $ perl -MJSON::ize -le '$j=jsonize("my.yaml"); print $j->{thingy};'
+
+ # plus yamls all the way down...
+
  # if you have PerlIO::gzip, this works
 
  $ perl -MJSON::ize -le '$j=jsonize("my.json.gz"); print $j->{thingy};'
@@ -84,9 +106,9 @@ sub looks_like_json {
 =head1 DESCRIPTION
 
 JSON::ize exports a function, C<jsonize()>, that will do what you mean with the argument. 
-If argument is a filename, it will try to read the file and decode it as JSON.
+If argument is a filename, it will try to read the file and decode it as JSON or YAML.
 If argument is a string that looks like JSON, it will try to encode it.
-If argument is a Perl hashref or arrayref, it will try to encode it.
+If argument is a Perl hashref or arrayref, it will try to encode it as JSON.
 
 The underlying L<JSON> object is
 
@@ -129,7 +151,7 @@ L<JSON>, L<JSON::XS>.
 
 =head1 LICENSE
 
-Copyright (c) 2018 Mark A. Jensen.
+Copyright (c) 2018, 2019 Mark A. Jensen.
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
